#
#  Copyright 1996-2013 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::OS::aix - AIX specific configuration information.
#
package Security::OS::aix;

use Exporter;
use strict;
use warnings "all";

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( init check );

sub init {
	print ( STDERR  "In Security::OS::aix::init()\n") if ( $main::opts{'d'} );

	$main::showmount = '/usr/bin/showmount';
	$main::exportsfile = '/etc/exports';
	$main::sudofile = '/etc/sudoers';
}

1;

__END__

=head1 NAME

Security::OS::aix

=head1 SYNOPSIS

Security::OS::aix::init();

=head1 DESCRIPTION

Sets variables for OS specific commands.

=head1 API

Defines the following API calls

=over 4

=item C<init()>

Init sets the following global variables:

=over 4

=item C<$main::showmount>

The location of the showmount command, used in the C<Security::exports> module.

=item C<$main::exportsfile>

The location of the exports file, used in C<Security::exports> module.

=item C<$main::sudofile>

The location of F<sudoers> file, used in C<Security::sudo> module.

=back

=back

=cut
