#
#  Copyright 1996-2013 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::OS::darwin - Darwin (Mac OS X) specific configuration information
#
package Security::OS::darwin;

use Exporter;
use POSIX;
use strict;
use warnings "all";

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( init check );

sub init {
	print ( STDERR  "In Security::OS::darwin::init()\n") if ( $main::opts{'d'} );

	$main::group0 = 'wheel';
	$main::showmount = '/usr/bin/showmount';
	$main::exportsfile = '/etc/exports';
	$main::kerneldir = '/System/Library/Extensions';
	$main::kernelmodlist = '/usr/sbin/kextstat -k | awk \' NR > 1 {print $6}\'';
	$main::securefile = '/etc/ttys';
	$main::sudofile = '/etc/sudoers';

	$main::login_length = POSIX::sysconf( 73 );

	$Security::library::sharedregex = qr(^lib[^/]*\.dylib$);
}

sub check {
	print ( STDERR  "In Security::OS::darwin::check()\n") if ( $main::opts{'d'} );

	&Security::rootlogin::check_ttys()
		if ( defined &Security::rootlogin::check_ttys );
}

1;

__END__

=head1 NAME

Security::OS::darwin

=head1 SYNOPSIS

&Security::OS::darwin::init();

&Security::OS::darwin::check();

=head1 DESCRIPTION

Sets variables for OS specific commands and runs OS specific checks.

=head1 API

Defines the following API calls

=over 4

=item C<init()>

Init sets the following global variables:

=over 4

=item C<$main::showmount>

The location of the showmount command, used in the C<Security::exports>
module.

=item C<$main::exportsfile>

The location of the exports file, used in C<Security::exports> module.

=item C<$main::sudofile>

The location of F<sudoers> file, used in C<Security::sudo> module.

=item C<$main::kerneldir>

The location of the kernel loadable modules, used in C<Security::kernel>
module.

=item C<$main::securefile>

The location of the list of ports root is allowed in on, used in
C<Security::rootlogin> module.

=back

=item C<check()>

Calls C<Security::rootlogin::check_ttys()> to check what root ports are
configured and compares it to what ports we know about.

=back

=cut
