#
#  Copyright 1996-2013 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::MD5 - MD5 digest generation module.
#
package Security::util::MD5;

use Security::db;
use Digest::MD5;
use Exporter;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( init check );

sub init {
	$Security::db::format = "MD5 \\((.*)\\) = (.*)";
}

sub check {
	my ($file) = @_;
	my ($md) = new Digest::MD5;
	my ($md_fd);

	open ($md_fd, $file) || return "MD5 ($file) = -1\n";
	$md->reset();
	$md->addfile($md_fd);
	my ($hex) = $md->hexdigest();
	close $md_fd;
	return "MD5 ($file) = $hex\n";
}

1;

__END__

=head1 NAME

Security::util::MD5 - module for generating MD5 digests

=head1 SYNOPSIS

Security::util::MD5::check($file)

=head1 DESCRIPTION

A wrapper routine around C<Digest::MD5> to return the checksum for a
given file.

=head1 API

The API calls provided by this module

=over 4

=item C<init ()>

Sets the global variable C<$main::format>.

=item C<check ($file)>

Returns a MD5 digest for the given file.  Needs to have read access for
the file to be checksummed.

=back

This module sets the following global variables

=over 4

=item <$main::format>

This is a regex that is used in a C<grep> routine to get the digest from
the filename, defaults to I<MD5\\((.*)\\) = (.*)>

=back

=head1 CONFIGURATION OPTIONS

None.

=head1 HISTORY

This module was created from the md5 script that I created many years ago.
When the generate_config.pl script came about, I decided to simplify the
code base and only have one copy of the routine. 

=head1 TODO

Abstract this API out better to support changing of digest routines.

=head1 SEE ALSO

L<Digest::MD5>

L<perl>

=cut
