#
#  Copyright 1996-2013 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::hostname - Custom hostname routine
#
package Security::util::hostname;

use Exporter;
use Sys::Hostname;
use Security::util::detaint;
use Net::DNS;
use strict;
use warnings "all";

our @ISA = qw(Exporter);
our @EXPORT = qw( security_hostname );

# Replacement function for the hostname call, to make sure we get the Fully
# Qualified Hostname (looking at you Ubuntu!
sub security_hostname {
	my ($host) = &hostname();

	return $host if ( $host =~ /\./ );

	# If we don't have any . in the hostname we must not have a FQHN
	if ( -f '/bin/hostname' ) {
		$host = `/bin/hostname -f 2> /dev/null`;
		chomp $host;

		($host) = detaint('hostname', $host);
		return $host if ( $host =~ /\./ );
	}

	# Try looking up the name in DNS
	my $res = Net::DNS::Resolver->new;
	my $query = $res->search($host);
 	if ($query) {
 		foreach my $rr ($query->answer) {
 			next unless $rr->type eq "A";
			($host) = detaint('hostname', $rr->name);
			return $host;
 		}
 	}

	# This is an error case, we could not find the FQHN
	return undef
}

1;

__END__

=head1 NAME

Security::util::hostname - Custom hostname routine

=head1 SYNOPSIS

use Security::util::hostname;

my $host = &security_hostname();

=head1 DESCRIPTION

=head1 method

=over 4

=item C<security_hostname()>

Will get the fully qualified hostname.

=back

=head1 SEE ALSO

L<Net::DNS>

L<Sys::Hostname>

=cut
