#
#  Copyright 1996-2013 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::print - Routines to report security violations
#
package Security::util::print;

use Exporter;
use Security::util::read_config;
use strict;
use warnings "all";

our @ISA = qw(Exporter);
our @EXPORT = qw( print_header print_data print_close );
my ($fh, $file_open, $smtp) = (undef, 0, undef);

sub check_fp {
	$main::opts{'M'} = "root\@$main::host" if ( ! defined $main::opts{'M'} );

	if ( !$file_open ) {

		# We're writing our output to the screen
		if ( $main::opts{'M'} eq '-' ) {
			$fh = \*STDOUT;
			print ($fh "$main::title\n");
			$file_open = 1;

		# Write output to a file, either relative (./*) or absolute (/*).
		} elsif ( $main::opts{'M'} =~ m|^(\.)?/|o ) {
			if (!open ($fh, ">$main::opts{'M'}" )) {
				# Use real die for the errors since we can't open the file
				die("Could not open $main::opts{'M'}\n");
			} 
			print ($fh "$main::title\n");
			$file_open = 1;

		# Send output via email
		} else { 
			&read_config('mailhost');
			if (!($smtp = Net::SMTP->new( $main::config{'mailhost'},
					'LocalAddr' => $main::host,
					'Hello' => $main::host,
					'Debug' => $main::opts{'d'},
					))) {

				# Use real die for the errors since we can't connect
			 	die("Could not connect to " . $main::config{'mailhost'}[0] . "\n");
			}
			$smtp->mail("root\@$main::host");
			$smtp->to($main::opts{'M'});
			$smtp->data();
			$smtp->datasend("To: $main::opts{'M'}\n");
			$smtp->datasend("From: root\@$main::host\n");
			$smtp->datasend("Subject: $main::title\n");
			$smtp->datasend("\n");

			$file_open = 2;
		}
	}
}

sub print_header {
	my ($msg) = @_;

	&check_fp();
	if ($file_open == 1) {
		print ($fh $msg);
	} else {
		$smtp->datasend($msg);
	}
}

sub _format_values {
	my ($field) = @_;
	my ($res) = '';

	if ( ref $field eq 'HASH' ) {
		$res = ' ' . join (' ', %$field);
	} elsif ( ref $field eq 'ARRAY' ) {
		$res = ' ' . join (' ', @$field);
	} elsif ( $field ne '1' ) {
		$res = qq{ $field};
	}
	return $res;
}

sub print_data {
	my ($header,%ary) = @_;
	print ( STDERR "In print_data($header, HASH)\n") if ( $main::opts{'d'} );
	my ($cnt) = 0;

	foreach my $i (sort keys %ary) {
		if (! $cnt ) {
			&print_header($header);
			$cnt=1;
		}
		if ( $file_open == 1) {
			print ($fh $i . _format_values($ary{$i}) . "\n");
		} else {
			$smtp->datasend($i . _format_values($ary{$i}) . "\n");
		}
	}
}

sub print_close {
	if ($file_open == 2) {
		$smtp->dataend();
		$smtp->quit;
	} elsif ($file_open == 1) {
		close $fh if ( defined $fh );
	}
	($fh, $file_open, $smtp) = (undef, 0, undef);
}

1;

__END__

=head1 NAME

Security::util::print - Routines to report security violations

=head1 SYNOPSIS

use Security::util::print;
&print_header(

=head1 DESCRIPTION

=head1 method

It provides the following method for other modules to use.

=over 4

=item C<print_header($header)>

Prints out the C<$header> string to the appropiate device.

=item C<print_data($msg, %hash)>

Prints out the C<$msg> (via C<print_header($msg)>) theo the appropiate
device then prints the content of C<%hash>.

=item C<print_close()>

Routine closes down the connection to the SMTP server or closes the file.

=back

=head1 SEE ALSO

=cut
