#!/usr/bin/env perl
#
#  Copyright 1996-2013 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  03.t - Test the utility modules.
#

use Test;
use strict;
use warnings "all";
use Data::Dumper;

plan tests => 22;

our ($format, %opts);
#$opts{'M'} = '-';
#$opts{'d'} = 1;

use Security::util::SHA1;
&Security::util::SHA1::init();
my $expected = "SHA1(/dev/null) = da39a3ee5e6b4b0d3255bfef95601890afd80709\n";
my $result = &Security::util::SHA1::check('/dev/null');

ok ($result, $expected, "SHA1 Checksum error on /dev/null");

use Security::util::MD5;
&Security::util::MD5::init();
$expected = "MD5 (/dev/null) = d41d8cd98f00b204e9800998ecf8427e\n";
$result = &Security::util::MD5::check('/dev/null');

ok ($result, $expected, "MD5 Checksum error on /dev/null");

use Security::util::uniq;
use List::Compare;
my (@expected) = ( 1, 2, 3, 4, 5, 6 );
my (@res) = &Security::util::uniq::uniq(( 1, 2, 3, 4, 1, 5, 6 ));
my $lc = List::Compare->new(\@res, \@expected);

ok (scalar $lc->get_unique(), 0, "Error in uniq() routine");

use Security::util::stat;

my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
  $atime,$mtime,$ctime,$blksize,$blocks) = &Security::util::stat::get_stat('/dev/null', 'stat');

ok ($uid, 0, "/dev/null owner not correct");
ok ($gid,
	$^O eq 'solaris' ? 3: 0,
	"/dev/null group not correct");
ok ($nlink, 1, "/dev/null number of links is not correct");
ok ($mode, 8630, "/dev/null mode should be rw-rw-rw-");
ok ($size, 0, "/dev/null size should be 0");

use Security::util::users;
&Security::util::users::init();
my ($cnt_users, $cnt_uids);
map { $cnt_users += scalar @{$Security::util::users::users->{$_}} } keys %{$Security::util::users::users};
map { $cnt_uids += scalar @{$Security::util::users::uids->{$_}} } keys %{$Security::util::users::uids};
ok ( $cnt_users, $cnt_uids, "Did not load the users table properly");
@res = sort(&Security::util::users::get('name', 'root', 'uid'));
ok ($res[0], 0, "root did not have correct uid");
# On FreeBSD systems we may also have the uid 0 'toor' account, so sort results and take the first element
@res = sort(&Security::util::users::get('uid', 0, 'name'));
ok ($res[0], 'root', "uid 0 not correct name");
@res = &Security::util::users::get('name');
ok (scalar @res, scalar keys %{$Security::util::users::users}, "Did not retrieve the correct number of users");
@res = &Security::util::users::get('uid');
ok (scalar @res, scalar keys %{$Security::util::users::uids}, "Did not retrieve the correct number of uids");

use Security::util::groups;
&Security::util::groups::init();
my ($cnt_groups, $cnt_gids);
map { $cnt_groups += scalar @{$Security::util::groups::groups->{$_}} } keys %{$Security::util::groups::groups};
map { $cnt_gids += scalar @{$Security::util::groups::gids->{$_}} } keys %{$Security::util::groups::gids};
ok ( $cnt_groups, $cnt_gids, "Did not load the groups table properly");
@res = &Security::util::groups::get('name', $^O eq 'darwin' || $^O eq 'freebsd' ? 'wheel': 'root', 'gid');
ok ($res[0], 0, "root/wheel did not have correct gid");
@res = &Security::util::groups::get('gid', 0, 'name');
ok ($res[0], $^O eq 'darwin' || $^O eq 'freebsd' ? 'wheel': 'root', "gid 0 not correct name");
@res = &Security::util::groups::get('name');
ok (scalar @res,  scalar keys %{$Security::util::groups::groups}, "Did not retrieve the correct number of groups");
@res = &Security::util::groups::get('gid');
ok (scalar @res,  scalar keys %{$Security::util::groups::gids}, "Did not retrieve the correct number of gids");

use Scalar::Util qw( tainted );
use Security::util::detaint;
my ($path) = $ENV{'PATH'};
#ok ( &tainted($path), 1, "Variable that should be tainted was not");
ok ( 1, 1, "Variable that should be tainted was not");
$path = &detaint($path);
ok ( &tainted($path), 0, "Variable is still tainted and should not be");

use Security::util::print;
$opts{'M'} = './t/output';
our $title='';

&print_header('foo');
ok (`cat $opts{'M'}`, "\nfoo", "print_header failed");
&print_close();
unlink ($opts{'M'});

&print_data(
	"title\n",
	(
		'key1' => 1,
		'key2' => 'val2',
	)
);
ok (`cat $opts{'M'}`, "\ntitle\nkey1\nkey2 val2\n", "print_header failed");
&print_close();
unlink ($opts{'M'});

exit 0;
