#!/usr/bin/env perl
#
#  Copyright 1996-2013 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  09.t - group entry testing.
#

use Test;
use strict;
use warnings "all";

plan tests => 22;

use Security::util::groups;
use Security::util::users;
use Security::group;
use Data::Dumper;

# For the regexs to test GID and group names.
use Security::passwd qw(!:DEFAULT);

our (%opts, %config);
#$opts{'d'} = 1;

# Setup defaults
$config{'yp'} = '';
$config{'ignoregid'} = [ ];
$config{'ignoregpasswd'} = [ 'badgroup' ];
$config{'ignoredupgpasswd'} = [ '', '' ];
$config{'ignoredupgid'} = [ '' ];
$config{'defaultpass'} = [ '0123456789abc' ];
our $group0 = 'wheel';

$Security::util::groups::groups = {
	$group0 => [ &User::grent::populate( $group0, '*', 0, 'root' ) ],
	'badwheel' => [ &User::grent::populate( 'badwheel', 'x', 0, 'root' ) ],
	'badgroup' => [ &User::grent::populate( 'badgroup', '', 1, '' ) ],
	'badgroup2' => [ &User::grent::populate( 'badgroup2', '', 2, '' ) ],
	'badgroup3' => [ &User::grent::populate( 'badgroup3', 'abc0123456789', 3, '' ) ],
	'badgroup4' => [ &User::grent::populate( 'badgroup4', 'abc0123456789', 4, '' ) ],
	'badgroup5' => [ &User::grent::populate( 'badgroup5', '0123456789abc', 5, '' ) ],
	'badgroup6' => [ &User::grent::populate( 'badgroup6', '!', 6, '' ) ],
	'badgroup7' => [ &User::grent::populate( 'badgroup7', '!!', 6, '' ) ],
	'reallyreallyreallyreallylongloginname' => [ &User::grent::populate( 'reallyreallyreallyreallylongloginname', 'LK', 8, '' ) ],
	'bad,char' => [ &User::grent::populate( 'bad,char', '*', 9, '' ) ],
	'badgroup9' => [ &User::grent::populate( 'badgroup9', '*LOCKED*', -10, '' ) ],
	'badgroup10' => [ &User::grent::populate( 'badgroup10', '*', 11, 'root toor' ) ],
};

# Sync the uids hash with the groups hash data
foreach my $name (keys %{$Security::util::groups::groups} ) {
	foreach my $pw ( @{$Security::util::groups::groups->{$name}} ) {
		push @{$Security::util::groups::gids->{$pw->gid}}, $pw;
	}
}

$Security::util::users::users = {
	'root' => [ &User::pwent::_populate( 'root', 'abc0123456789', 0, 0, undef, '', 'Super User', '/', '/bin/sh', 0 ) ],
};

# Sync the uids hash with the users hash data
foreach my $name (keys %{$Security::util::users::users} ) {
	foreach my $pw ( @{$Security::util::users::users->{$name}} ) {
		push @{$Security::util::users::uids->{$pw->uid}}, $pw;
	}
}


sub print_data {}

&Security::group::init();
&Security::group::check();

# Make sure we found all the bad root accounts
ok ( scalar keys %Security::group::gid0, 1, "Did not find right number of bad gid 0 account");
ok ( $Security::group::gid0{$group0}, undef, "Wrong bad gid 0 account found");
ok ( $Security::group::gid0{'badwheel'}, 1, "Wrong bad gid 0 account found");

# Now check for no passwords
ok ( scalar keys %Security::group::nopass, 1, "Did not find right number of groups w/ missing passwords");
ok ( $Security::group::nopass{'badgroup'}, undef, "Wrong missing password groups found");
ok ( $Security::group::nopass{'badgroup2'}, '(group)', "Wrong missing password groups found");

# Now check for duplicate passwords
ok ( scalar keys %Security::group::dupgpasswd, 2, "Did not find right number of groups w/ duplicate passwords");
ok ( $Security::group::dupgpasswd{'badgroup3'}, 'badgroup3 and badgroup4', "Duplicate password found for badgroup4");
ok ( $Security::group::dupgpasswd{'badgroup4'}, 'badgroup3 and badgroup4', "Duplicate password found for badgroup4");

# Now check for default passwords
ok ( scalar keys %Security::group::defaultpw, 1, "Did not find right number of groups w/ default password");
ok ( $Security::group::defaultpw{'badgroup5'}, 1, "Default password not found for badgroup5");

# Now check for duplicate GIDs
ok ( scalar keys %Security::group::dupgid, 2, "Did not find right number of groups w/ duplicate GIDs");
ok ( $Security::group::dupgid{'badgroup6'}, 'badgroup6 and badgroup7', "Duplicate group not found for badgroup6");
ok ( $Security::group::dupgid{'badgroup7'}, 'badgroup6 and badgroup7', "Duplicate group not found for badgroup7");

# Now check for bad login info (names, GID)
ok ( scalar keys %Security::group::badlogin, 2, "Did not find right number of groups w/ bad login info");
ok ( $Security::group::badlogin{'reallyreallyreallyreallylongloginname'}, 1, "Did not find group with really long name");
ok ( $Security::group::badlogin{'bad,char'}, 1, "Did not find group with invalid charater");
ok ( scalar keys %Security::group::badgid, 1, "Did not find right number of groups w/ bad GID info");
ok ( $Security::group::badgid{'badgroup9'}, 1, "Did not find group with bad GID");

# Now check for bad members
ok ( scalar keys %Security::group::badmembers, 1, "Did not find right number of groups w/ bad members");
ok ( $Security::group::badmembers{$group0}, undef, "Found group with bad member (and should not have)");
ok ( $Security::group::badmembers{'badgroup10'}, 'toor', "Did not find group with bad member");

exit 0;
